pub enum Error {
OutOfLowerBound(f64),
OutOfUpperBound(f64),
Nan,
}Expand description
An error arising from this module’s TryFrom trait implementation for its
Signifix type.
Variants
OutOfLowerBound(f64)
The given number is below the lower bound ±1.000 (= ±1 024 ^ 0).
OutOfUpperBound(f64)
The given number is above the upper bound ±1 023 Yi (≈ ±1 024 ^ 9)
of the uppermost binary prefix yobi (Yi = 1 024 ^ 8).
Nan
The given number is actually not a number (NaN).